from distutils.core import setup

setup(
    name         = 'zhou',
    version      = '1.0.0',
    py_modules   = ['cz_use'],
    author       = 'changzhi_zhou',
    url          = 'http://baidu.com',
    description  = 'A simple printer of hhh'
)